@@ -58,47 +58,53 @@ If-Modified-Since:, Range:, If-Range:, If-Unmodified-Since:.
 fileApp :: ClassicAppSpec -> FileAppSpec -> FileRoute -> Application
 fileApp cspec spec filei req = do
     RspSpec st body <- case method of
-        "GET"  -> processGET  hinfo ishtml rfile
-        "HEAD" -> processHEAD hinfo ishtml rfile
-        _      -> return notAllowed
+        Right GET  -> processGET  hinfo ishtml rfile
+        Right HEAD -> processHEAD hinfo ishtml rfile
+        _          -> return notAllowed
     (response, mlen) <- case body of
-            NoBody                 -> return $ noBody st
-            BodyStatus -> statusBody st <$> liftIO (getStatusInfo cspec spec langs st)
-            BodyFileNoBody hdr     -> return $ bodyFileNoBody st hdr
-            BodyFile hdr afile rng -> return $ bodyFile st hdr afile rng
+            NoBody                 -> noBody st
+            BodyStatus             -> bodyStatus st
+            BodyFileNoBody hdr     -> bodyFileNoBody st hdr
+            BodyFile hdr afile rng -> bodyFile st hdr afile rng
     liftIO $ logger cspec req st mlen
     return response
   where
     hinfo = HandlerInfo spec req file langs
-    method = requestMethod req
+    method = parseMethod $ requestMethod req
     path = pathinfoToFilePath req filei
     file = addIndex spec path
     ishtml = isHTML spec file
     rfile = redirectPath spec path
     langs = langSuffixes req
-    noBody st = (responseLBS st hdr "", Nothing)
-      where
-        hdr = addServer cspec []
+    zdater = dater cspec
+    noBody st = do
+        hdr <- liftIO . addDate zdater $ addServer cspec []
+        return (responseLBS st hdr "", Nothing)
+    bodyStatus st = liftIO (getStatusInfo cspec spec langs st)
+                >>= statusBody st
     statusBody st StatusNone = noBody st
-    statusBody st (StatusByteString bd) = (responseLBS st hdr bd, Just (len bd))
+    statusBody st (StatusByteString bd) = do
+        hdr <- liftIO . addDate zdater $ addServer cspec textPlainHeader
+        return (responseLBS st hdr bd, Just (len bd))
       where
         len = fromIntegral . BL.length
-        hdr = addServer cspec textPlainHeader
-    statusBody st (StatusFile afile len) = (ResponseFile st hdr fl mfp, Just len)
+    statusBody st (StatusFile afile len) = do
+        hdr <- liftIO . addDate zdater $ addServer cspec textHtmlHeader
+        return (ResponseFile st hdr fl mfp, Just len)
       where
-        hdr = addServer cspec textHtmlHeader
         mfp = Just (FilePart 0 len)
         fl = pathString afile
-    bodyFileNoBody st hdr = (responseLBS st hdr' "", Nothing)
-      where
-        hdr' = addServer cspec hdr
-    bodyFile st hdr afile rng = (ResponseFile st hdr' fl mfp, Just len)
+    bodyFileNoBody st hdr = do
+        hdr' <- liftIO . addDate zdater $ addServer cspec hdr
+        return (responseLBS st hdr' "", Nothing)
+    bodyFile st hdr afile rng = do
+        hdr' <- liftIO . addDate zdater $ addLength len $ addServer cspec hdr
+        return (ResponseFile st hdr' fl mfp, Just len)
       where
         (len, mfp) = case rng of
             -- sendfile of Linux does not support the entire file
             Entire bytes    -> (bytes, Just (FilePart 0 bytes))
             Part skip bytes -> (bytes, Just (FilePart skip bytes))
-        hdr' = addLength len $ addServer cspec hdr
         fl = pathString afile
 
 ----------------------------------------------------------------
@@ -115,11 +121,12 @@ tryGet hinfo False = tryGetFile hinfo False id
 
 tryGetFile :: HandlerInfo -> Bool -> Lang -> Rsp
 tryGetFile (HandlerInfo spec req file _) ishtml lang = do
-    finfo <- liftIO $ (getFileInfo spec) (lang file)
+    finfo <- liftIO $ getFileInfo spec (lang file)
     let mtime = fileInfoTime finfo
         size = fileInfoSize finfo
         sfile = fileInfoName finfo
-        hdr = newHeader ishtml (pathByteString file) mtime
+        date = fileInfoDate finfo
+        hdr = newHeader ishtml (pathByteString file) date
         Just pst = ifmodified req size mtime -- never Nothing
                <|> ifunmodified req size mtime
                <|> ifrange req size mtime
@@ -144,10 +151,11 @@ tryHead hinfo False= tryHeadFile hinfo False id
 
 tryHeadFile :: HandlerInfo -> Bool -> Lang -> Rsp
 tryHeadFile (HandlerInfo spec req file _) ishtml lang = do
-    finfo <- liftIO $ (getFileInfo spec) (lang file)
+    finfo <- liftIO $ getFileInfo spec (lang file)
     let mtime = fileInfoTime finfo
         size = fileInfoSize finfo
-        hdr = newHeader ishtml (pathByteString file) mtime
+        date = fileInfoDate finfo
+        hdr = newHeader ishtml (pathByteString file) date
         Just pst = ifmodified req size mtime -- never Nothing
                <|> Just (Full ok200)
     case pst of
@@ -165,7 +173,7 @@ tryRedirect (HandlerInfo spec req _ langs) (Just file) =
 
 tryRedirectFile :: HandlerInfo -> Lang -> Rsp
 tryRedirectFile (HandlerInfo spec req file _) lang = do
-    _ <- liftIO $ (getFileInfo spec) (lang file)
+    _ <- liftIO $ getFileInfo spec (lang file)
     return $ RspSpec movedPermanently301 (BodyFileNoBody hdr)
   where
     hdr = redirectHeader req
